@@ -4,12 +4,10 @@ from __future__ import unicode_literals
 from datetime import date
 
 from .. import Provider as SsnProvider
-from faker.providers.date_time import Provider as DateTimeProvider
 
 
 class Provider(SsnProvider):
-    @classmethod
-    def ssn(cls):
+    def ssn(self):
         """
         Ukrainian "Реєстраційний номер облікової картки платника податків"
         also known as "Ідентифікаційний номер фізичної особи".
@@ -17,13 +15,13 @@ class Provider(SsnProvider):
         digits = []
 
         # Number of days between 1899-12-31 and a birth date
-        for digit in str((DateTimeProvider.date_object() -
+        for digit in str((self.generator.date_object() -
                           date(1899, 12, 31)).days):
             digits.append(int(digit))
 
         # Person's sequence number
         for _ in range(4):
-            digits.append(cls.random_int(0, 9))
+            digits.append(self.random_int(0, 9))
 
         checksum = (digits[0]*-1 + digits[1]*5 + digits[2]*7 + digits[3]*9 +
                     digits[4]*4 + digits[5]*6 + digits[6]*10 + digits[7]*5 +
